/*
 * This file is a component of thundr, a software library from 3wks.
 * Read more: http://www.3wks.com.au/thundr
 * Copyright (C) 2013 3wks, <thundr@3wks.com.au>
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.threewks.thundr.mailgun;

import com.threewks.thundr.mailgun.Log.LogItem;

/**
 * Provides basic Mailgun integration.
 * Currently this provides the ability to:
 * <ul>
 * <li>Send email - {@link #sendEmail(String, String, String, String, String)}: <a href="http://documentation.mailgun.com/user_manual.html#sending-via-api">API here</a></li>
 * <li>Check logs - {@link #log(Integer, Integer)}: <a href="http://documentation.mailgun.com/user_manual.html#logs">API here</a></li>
 * </ul>
 */
public interface Mailgun {
	/**
	 * Returns the domain registered for use with mailgun.
	 * i.e. mydomain.mailgun.org
	 * 
	 * @return the domain registered for use with mailgun
	 */
	public String getDomain();

	/**
	 * Returns a {@link Log} which contains the {@link LogItem} results from an invocation to the mailgun log api.
	 * 
	 * @param skip
	 * @param limit
	 * @return a {@link Log}, which contains {@link LogItem}s with the results from a mailgun log query
	 */
	public Log log(Integer skip, Integer limit);

	/**
	 * Sends an email using the mailgun send api.
	 * 
	 * @param from
	 * @param to
	 * @param replyTo
	 * @param subject
	 * @param htmlBody
	 * @return a {@link MessageSend} which contains the results of the send operation.
	 */
	public MessageSend sendEmail(String from, String to, String replyTo, String subject, String htmlBody);

	public enum Service {
		Log("log"),
		Messages("messages");

		private String service;

		private Service(String service) {
			this.service = service;
		}

		public String service() {
			return service;
		}
	}
}
